==> kmymoney-5.0.6.tar.xz: kmymoney-5.0.6/kmymoney/plugins/csv/import/csvimporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aganders93@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ca]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[cs]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[de]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[en_GB]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[es]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[fr]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[gl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[it]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[nl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pt]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ru]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[sv]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[uk]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[x-test]": "xxAllan Anderson,Łukasz Wojniłowiczxx"
            }
        ],
        "Description": "Add CSV importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des de CSV al KMyMoney",
        "Description[ca]": "Afegeix la importació des de CSV al KMyMoney",
        "Description[de]": "Fügt CSV-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add CSV importing to KMyMoney",
        "Description[es]": "Añade importación CSV a KMyMoney",
        "Description[fr]": "Ajoute l'importation « CSV » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar CSV en KMyMoney",
        "Description[it]": "Aggiunge l'importazione CSV a KMymoney",
        "Description[ko]": "KMyMoney에 CSV 가져오기를 추가",
        "Description[nl]": "Voeg CSV importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie CSV do KMyMoney",
        "Description[pt]": "Adição da importação de CSV para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação CSV no KMyMoney",
        "Description[sk]": "Pridať CSV importovanie do KMyMoney",
        "Description[sv]": "Lägg till CSV-import till KMyMoney",
        "Description[uk]": "Імпортування даних CSV у KMyMoney",
        "Description[x-test]": "xxAdd CSV importing to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "document-import",
        "Id": "csvimporter",
        "License": "GPL",
        "Name": "CSV Importer",
        "Name[ca@valencia]": "Importador de CSV",
        "Name[ca]": "Importador de CSV",
        "Name[cs]": "Importér CSV",
        "Name[de]": "CSV-Import",
        "Name[en_GB]": "CSV Importer",
        "Name[es]": "Importador CSV",
        "Name[fr]": "Importateur CSV",
        "Name[gl]": "Importador de CSV",
        "Name[it]": "Strumento di importazione CSV",
        "Name[nl]": "CSV-importeerprogramma",
        "Name[pl]": "Importer CSV",
        "Name[pt]": "Importação de CSV",
        "Name[pt_BR]": "Importador CSV",
        "Name[sk]": "Importér CSV",
        "Name[sv]": "CSV-import",
        "Name[uk]": "Імпортування CSV",
        "Name[x-test]": "xxCSV Importerxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.1.0.orig.tar.xz: kmymoney-5.1.0/kmymoney/plugins/csv/import/csvimporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aganders93@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ca]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[cs]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[de]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[en_GB]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[es]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[eu]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[fr]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[gl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[it]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ko]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[nl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pt]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ru]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[sk]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[sv]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[uk]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[x-test]": "xxAllan Anderson,Łukasz Wojniłowiczxx"
            }
        ],
        "Description": "Add CSV importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des de CSV al KMyMoney",
        "Description[ca]": "Afegeix la importació des de CSV al KMyMoney",
        "Description[de]": "Fügt CSV-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add CSV importing to KMyMoney",
        "Description[es]": "Añade importación CSV a KMyMoney",
        "Description[eu]": "CSV inportazioa gehitzen dio KMyMoneyri ",
        "Description[fr]": "Ajoute l'importation « CSV » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar CSV en KMyMoney",
        "Description[it]": "Aggiunge l'importazione CSV a KMymoney",
        "Description[ko]": "KMyMoney에 CSV 가져오기 추가",
        "Description[nl]": "Voeg CSV importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie CSV do KMyMoney",
        "Description[pt]": "Adição da importação de CSV para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação CSV no KMyMoney",
        "Description[sk]": "Pridať CSV importovanie do KMyMoney",
        "Description[sv]": "Lägg till CSV-import till KMyMoney",
        "Description[uk]": "Імпортування даних CSV у KMyMoney",
        "Description[x-test]": "xxAdd CSV importing to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "document-import",
        "Id": "csvimporter",
        "License": "GPL",
        "Name": "CSV Importer",
        "Name[ca@valencia]": "Importador de CSV",
        "Name[ca]": "Importador de CSV",
        "Name[cs]": "Importér CSV",
        "Name[de]": "CSV-Import",
        "Name[en_GB]": "CSV Importer",
        "Name[es]": "Importador CSV",
        "Name[eu]": "CSV-inportatzailea",
        "Name[fr]": "Importateur CSV",
        "Name[gl]": "Importador de CSV",
        "Name[it]": "Strumento di importazione CSV",
        "Name[ko]": "CSV 가져오기 도구",
        "Name[nl]": "CSV-importeerprogramma",
        "Name[pl]": "Importer CSV",
        "Name[pt]": "Importação de CSV",
        "Name[pt_BR]": "Importador CSV",
        "Name[ru]": "Импорт CSV",
        "Name[sk]": "Importér CSV",
        "Name[sv]": "CSV-import",
        "Name[uk]": "Імпортування CSV",
        "Name[x-test]": "xxCSV Importerxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
